@@ -142,8 +142,7 @@ def pipeline(
                     ticker, begin=now, end=begin, interval=interval,
                 )
                 if df.empty: # If the server gives us no data, break to avoid error
-                    logging.info("\n")
-                    logging.info("Historic data does not reach end date. Moving to next asset.")
+                    logging.debug("Historic data does not reach end date. Moving to next asset.")
                     break
                 else:
                     # If the server does give us data parse and add to db ... 
